==> webkitgtk_2.4.10.orig.tar.xz: webkitgtk-2.4.10/Source/WebCore/rendering/RenderTableCaption.cpp <==
/*
 * Copyright (C) 2011 Robert Hogan <robert@roberthogan.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "RenderTableCaption.h"

#include "RenderTable.h"

namespace WebCore {

RenderTableCaption::RenderTableCaption(Element& element, PassRef<RenderStyle> style)
    : RenderBlockFlow(element, std::move(style))
{
}

RenderTableCaption::~RenderTableCaption()
{
}

LayoutUnit RenderTableCaption::containingBlockLogicalWidthForContent() const
{
    RenderBlock* cb = containingBlock();
    return cb->logicalWidth();
}

void RenderTableCaption::insertedIntoTree()
{
    RenderBlockFlow::insertedIntoTree();

    table()->addCaption(this);
}

void RenderTableCaption::willBeRemovedFromTree()
{
    RenderBlockFlow::willBeRemovedFromTree();

    table()->removeCaption(this);
}

RenderTable* RenderTableCaption::table() const
{
    return toRenderTable(parent());
}

}

==> webkitgtk-2.7.2.tar.xz: webkitgtk-2.7.2/Source/WebCore/rendering/RenderTableCaption.cpp <==
/*
 * Copyright (C) 2011 Robert Hogan <robert@roberthogan.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "RenderTableCaption.h"

#include "RenderTable.h"

namespace WebCore {

RenderTableCaption::RenderTableCaption(Element& element, PassRef<RenderStyle> style)
    : RenderBlockFlow(element, WTF::move(style))
{
}

RenderTableCaption::~RenderTableCaption()
{
}

LayoutUnit RenderTableCaption::containingBlockLogicalWidthForContent() const
{
    RenderBlock* cb = containingBlock();
    return cb->logicalWidth();
}

void RenderTableCaption::insertedIntoTree()
{
    RenderBlockFlow::insertedIntoTree();

    table()->addCaption(this);
}

void RenderTableCaption::willBeRemovedFromTree()
{
    RenderBlockFlow::willBeRemovedFromTree();

    table()->removeCaption(this);
}

RenderTable* RenderTableCaption::table() const
{
    return downcast<RenderTable>(parent());
}

}
